==> mx-packageinstaller-pkglist_19.07.01.tar.xz: mx-packageinstaller-pkglist/hungarian_firefox.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Hungarian_Firefox
</name>

<description>
   <am>Hungarian localisation of Firefox</am>
   <ar>Hungarian localisation of Firefox</ar>
   <bg>Hungarian localisation of Firefox</bg>
   <ca>Localització de Firefox en Hongarès</ca>
   <cs>Hungarian localisation of Firefox</cs>
   <da>Ungarsk oversættelse af Firefox</da>
   <de>Ungarische Lokalisierung von Firefox</de>
   <el>Ουγγρικός εντοπισμός του Firefox</el>
   <en>Hungarian localisation of Firefox</en>
   <es>Hungarian localisation of Firefox</es>
   <et>Hungarian localisation of Firefox</et>
   <eu>Hungarian localisation of Firefox</eu>
   <fa>Hungarian localisation of Firefox</fa>
   <fi>Hungarian localisation of Firefox</fi>
   <fr>Localisation hongroise pour Firefox</fr>
   <he_IL>Hungarian localisation of Firefox</he_IL>
   <hi>Hungarian localisation of Firefox</hi>
   <hr>Hungarian localisation of Firefox</hr>
   <hu>Hungarian localisation of Firefox</hu>
   <id>Hungarian localisation of Firefox</id>
   <is>Hungarian localisation of Firefox</is>
   <it>Localizzazione ungherese di Firefox</it>
   <ja_JP>Hungarian localisation of Firefox</ja_JP>
   <ja>Hungarian localisation of Firefox</ja>
   <kk>Hungarian localisation of Firefox</kk>
   <ko>Hungarian localisation of Firefox</ko>
   <lt>Hungarian localisation of Firefox</lt>
   <mk>Hungarian localisation of Firefox</mk>
   <nb>Hungarian localisation of Firefox</nb>
   <nl>Hongaarse lokalisatie van Firefox</nl>
   <pl>Węgierska lokalizacja przeglądarki Firefox</pl>
   <pt_BR>Húngaro Localização para Firefox</pt_BR>
   <pt>Húngaro Localização para Firefox</pt>
   <ro>Hungarian localisation of Firefox</ro>
   <ru>Hungarian localisation of Firefox</ru>
   <sk>Hungarian localisation of Firefox</sk>
   <sl>Hungarian localisation of Firefox</sl>
   <sq>Hungarian localisation of Firefox</sq>
   <sr>Hungarian localisation of Firefox</sr>
   <sv>Ungersk lokalisering av Firefox</sv>
   <tr>Hungarian localisation of Firefox</tr>
   <uk>Hungarian локалізація Firefox</uk>
   <zh_CN>Hungarian localisation of Firefox</zh_CN>
   <zh_TW>Hungarian localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
firefox-l10n-xpi-hu
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
firefox-l10n-xpi-hu
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.09.02.tar.xz: mx-packageinstaller-pkglist/hungarian_firefox.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Hungarian_Firefox
</name>

<description>
   <am>Hungarian localisation of Firefox</am>
   <ar>Hungarian localisation of Firefox</ar>
   <bg>Hungarian localisation of Firefox</bg>
   <ca>Localització de Firefox en Hongarès</ca>
   <cs>Hungarian localisation of Firefox</cs>
   <da>Ungarsk oversættelse af Firefox</da>
   <de>Ungarische Lokalisierung von Firefox</de>
   <el>Ουγγρικός εντοπισμός του Firefox</el>
   <en>Hungarian localisation of Firefox</en>
   <es>Localización Húngara de Firefox</es>
   <et>Hungarian localisation of Firefox</et>
   <eu>Hungarian localisation of Firefox</eu>
   <fa>Hungarian localisation of Firefox</fa>
   <fi>Hungarian localisation of Firefox</fi>
   <fr>Localisation hongroise pour Firefox</fr>
   <he_IL>Hungarian localisation of Firefox</he_IL>
   <hi>Hungarian localisation of Firefox</hi>
   <hr>Hungarian localisation of Firefox</hr>
   <hu>Hungarian localisation of Firefox</hu>
   <id>Hungarian localisation of Firefox</id>
   <is>Hungarian localisation of Firefox</is>
   <it>Localizzazione ungherese di Firefox</it>
   <ja_JP>Hungarian localisation of Firefox</ja_JP>
   <ja>Hungarian localisation of Firefox</ja>
   <kk>Hungarian localisation of Firefox</kk>
   <ko>Hungarian localisation of Firefox</ko>
   <lt>Hungarian localisation of Firefox</lt>
   <mk>Hungarian localisation of Firefox</mk>
   <nb>Hungarian localisation of Firefox</nb>
   <nl>Hongaarse lokalisatie van Firefox</nl>
   <pl>Węgierska lokalizacja przeglądarki Firefox</pl>
   <pt_BR>Húngaro Localização para Firefox</pt_BR>
   <pt>Húngaro Localização para Firefox</pt>
   <ro>Hungarian localisation of Firefox</ro>
   <ru>Венгерская локализация Firefox</ru>
   <sk>Hungarian localisation of Firefox</sk>
   <sl>Hungarian localisation of Firefox</sl>
   <sq>Hungarian localisation of Firefox</sq>
   <sr>Hungarian localisation of Firefox</sr>
   <sv>Ungersk lokalisering av Firefox</sv>
   <tr>Hungarian localisation of Firefox</tr>
   <uk>Hungarian локалізація Firefox</uk>
   <zh_CN>Hungarian localisation of Firefox</zh_CN>
   <zh_TW>Hungarian localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
firefox-l10n-xpi-hu
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
firefox-l10n-xpi-hu
</uninstall_package_names>
</app>
